==> _private_chat-0.0.5.tar.gz: lib/connection_status/widgets/widget_user_builder.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get/get.dart';
import 'package:_private_chat/_private_chat.dart';
import 'package:_private_chat/utils/utils.dart';
import 'package:_private_core/_private_core.dart';

class WidgetUserConnectionStatusBuilder extends StatelessWidget {
  //personalStatus can is null => case don't use app
  //personalStatus can is bool => online
  //personalStatus is int if not online and that is lasttime login of user
  final Widget Function(
    dynamic personalStatus,
    ConversationStatus conversationStatus,
    String? conversationId,
    bool isBlockedFromMe,
    bool isMutedFromMe,
    bool isBlockedFromTheir,
    bool isMutedFromTheir,
  ) builder;
  final String id;
  const WidgetUserConnectionStatusBuilder({
    Key? key,
    required this.id,
    required this.builder,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ConnectionStatusBloc, ConnectionStatusState>(
      bloc: Get.find<ConnectionStatusBloc>(),
      buildWhen: (previous, current) {
        return previous.connectionStatusByKeys[id] !=
                current.connectionStatusByKeys[id] ||
            previous.blocked.contains(id) != current.blocked.contains(id) ||
            previous.muted.contains(id) != current.muted.contains(id);
      },
      builder: (_, state) {
        Map? data = state.connectionStatusByKeys[id];
        return builder(
          data?[DB_KEY_PERSONAL],
          ConversationStatus.values.byName(
              data?[DB_KEY_CONVERSATION] ?? ConversationStatus.none.name),
          data?[DB_KEY_CONVERSATION_ID],
          state.blocked.contains(id),
          state.muted.contains(id),
          data?[DB_KEY_BLOCKED]?.contains(loggedFirebaseId) ?? false,
          data?[DB_KEY_MUTED]?.contains(loggedFirebaseId) ?? false,
        );
      },
    );
  }
}

==> _private_chat-0.0.33.tar.gz: lib/connection_status/widgets/widget_user_builder.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get/get.dart';
import 'package:_private_chat/_private_chat.dart';
import 'package:_private_chat/utils/utils.dart';
import 'package:_private_core/_private_core.dart';

class WidgetUserConnectionStatusBuilder extends StatelessWidget {
  //personalStatus can is null => case don't use app
  //personalStatus can is bool => online
  //personalStatus is int if not online and that is lasttime login of user
  final Widget Function(
    dynamic personalStatus,
    ConversationStatus conversationStatus,
    String? conversationId,
    bool isBlockedFromMe,
    bool isMutedFromMe,
    bool isBlockedFromTheir,
    bool isMutedFromTheir,
  ) builder;
  final String id;
  const WidgetUserConnectionStatusBuilder({
    Key? key,
    required this.id,
    required this.builder,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<ConnectionStatusBloc, ConnectionStatusState>(
      bloc: Get.find<ConnectionStatusBloc>(),
      buildWhen: (previous, current) {
        return previous.connectionStatusByKeys[id] !=
                current.connectionStatusByKeys[id] ||
            previous.blocked.contains(id) != current.blocked.contains(id) ||
            previous.muted.contains(id) != current.muted.contains(id);
      },
      builder: (_, state) {
        Map? data = state.connectionStatusByKeys[id];
        return builder(
          data?[DB_KEY_PERSONAL],
          ConversationStatus.values.byName(
              data?[DB_KEY_CONVERSATION] ?? ConversationStatus.none.name),
          data?[DB_KEY_CONVERSATION_ID],
          state.blocked.contains(id),
          state.muted.contains(id),
          data?[DB_KEY_BLOCKED]?.contains(loggedUsername) ?? false,
          data?[DB_KEY_MUTED]?.contains(loggedUsername) ?? false,
        );
      },
    );
  }
}
